==> gamemaster-0.0.6.tar.gz: gamemaster-0.0.6/client.php <==
<?php
error_reporting(E_ALL);

// Example on how to talk to GameMaster through PHP.
// Copyright Martin Persson System & Design 2009
// View this file with tabstop=4, shiftwidth=4, or face the consequences.
// And if you use spaces for indentation, then you are simply WRONG.

print "Starting script...\n";
$command = array('command' => 'new',
		'length' => 120,
		'name' => 'A test session!',
		'game' => 'Counter-Strike Source',
		'executable' => '/storage/temp/counter-strike_source/srcds_run -console -game cstrike +maxplayers 4 +map de_dust -port 27015  +exec /storage/temp/counter-strike_source/cstrike/temp_config.cfg',
		'working_dir' => '/storage/temp/counter-strike_source',
		'config_filename' => '/storage/temp/counter-strike_source/cstrike/temp_config.cfg',
		'config_contents' => "sv_password kebab\n");

$address = '127.0.0.1';
$port = 4554;

# We need to append a newline at the end to indicate to the Perl-based
# server that the input is ending.
$json_command = json_encode($command) . "\n";

print "Creating socket...\n";
if (($socket = socket_create(AF_INET, SOCK_STREAM,
		getprotobyname('tcp'))) === FALSE) {
	die("Unable to create TCP socket.\n");
}

print "Connecting to remote host $address on port $port...\n";
if (!socket_connect($socket, $address, $port)) {
	die("Unable to connect to remote host.\n");
}

print "Writing command to socket...\n";
if (($bytes_written = socket_write($socket, $json_command)) === FALSE) {
	die("Unable to write JSON encoded data to socket.\n");
}

print "Reading response from socket...\n";
if (($response_json = socket_read($socket, 2048, PHP_NORMAL_READ)) === FALSE) {
	die("Unable to read server response from socket.\n");
}
print "Closing socket...\n";
socket_close($socket);

# Remove trailing extra newline.
$response_json = chop($response_json);

$response = json_decode($response_json, true);

print "Server response: $response_json\n";

if ($response['status'] == 'error') {
	print "An error occured: \"" . $response['message'] . "\n";
} else {

	if ($response['response'] == 'list') {

		print "'List' command response received.\n";

	foreach ($response['sessions'] as $id => $session) {
		print "Session \"" . $session['name'] . "\", ID: " . $id .
				", Length: " . $session['length'] . ", Seconds remaining: " .
				$session['time_remaining'] . "\n";
	}

	} elseif ($response['response'] == 'new') {

		print "'New' command response received.\n";

	} elseif ($response['response'] == 'terminate') {

		print "'Terminate' command response received.\n";

	} elseif ($response['response'] == 'modify') {

		print "'Modify' command response received.\n";

	} else {
		print "Oh my goodness. What the hell is this? Master Shake is so great."
				. " Unknown command response received.\n";
	}
}

?>

==> gamemaster-0.0.11.tar.gz: gamemaster-0.0.11/client.php <==
<?php
error_reporting(E_ALL);

// Example on how to talk to GameMaster through PHP.
// Copyright Martin Persson System & Design 2009
// View this file with tabstop=4, shiftwidth=4, or face the consequences.
// And if you use spaces for indentation, then you are simply WRONG.

print "Starting script...\n";
$command = array('command' => 'new',
		'length' => 120,
		'name' => 'A test session!',
		'game' => 'Counter-Strike Source',
		'executable' => '/storage/temp/counter-strike_source/srcds_run -console -game cstrike +maxplayers 4 +map de_dust -port 27015  +exec /storage/temp/counter-strike_source/cstrike/temp_config.cfg',
		'working_dir' => '/storage/temp/counter-strike_source',
		'config_filename' => '/storage/temp/counter-strike_source/cstrike/temp_config.cfg',
		'config_contents' => "sv_password kebab\n",
		'username' => 'localadmin',
		'password' => 'secret');

$address = '127.0.0.1';
$port = 4554;

# We need to append a newline at the end to indicate to the Perl-based
# server that the input is ending.
$json_command = json_encode($command) . "\n";

print "Creating socket...\n";
if (($socket = socket_create(AF_INET, SOCK_STREAM,
		getprotobyname('tcp'))) === FALSE) {
	die("Unable to create TCP socket.\n");
}

print "Connecting to remote host $address on port $port...\n";
if (!socket_connect($socket, $address, $port)) {
	die("Unable to connect to remote host.\n");
}

print "Writing command to socket...\n";
if (($bytes_written = socket_write($socket, $json_command)) === FALSE) {
	die("Unable to write JSON encoded data to socket.\n");
}

print "Reading response from socket...\n";
if (($response_json = socket_read($socket, 2048, PHP_NORMAL_READ)) === FALSE) {
	die("Unable to read server response from socket.\n");
}
print "Closing socket...\n";
socket_close($socket);

# Remove trailing extra newline.
$response_json = chop($response_json);

$response = json_decode($response_json, true);

print "Server response: $response_json\n";

if ($response['status'] == 'error') {
	print "An error occured: \"" . $response['message'] . "\n";
} else {

	if ($response['response'] == 'list') {

		print "'List' command response received.\n";

	foreach ($response['sessions'] as $id => $session) {
		print "Session \"" . $session['name'] . "\", ID: " . $id .
				", Length: " . $session['length'] . ", Seconds remaining: " .
				$session['time_remaining'] . "\n";
	}

	} elseif ($response['response'] == 'new') {

		print "'New' command response received.\n";

	} elseif ($response['response'] == 'terminate') {

		print "'Terminate' command response received.\n";

	} elseif ($response['response'] == 'modify') {

		print "'Modify' command response received.\n";

	} else {
		print "Oh my goodness. What the hell is this? Master Shake is so great."
				. " Unknown command response received.\n";
	}
}

?>
